@@ -10,13 +10,11 @@ class Kola(AppCallBacksMixin):
     """
 
     debug = False
-    conn_class = None
     blueprints = None
     got_first_request = False
 
-    def __init__(self, conn_class=None):
+    def __init__(self):
         AppCallBacksMixin.__init__(self)
-        self.conn_class = conn_class or Connection
         self.blueprints = dict()
 
     def register_blueprint(self, blueprint):
